@@ -5,7 +5,7 @@ use strict;
 use warnings FATAL => 'all';
 
 use constant {
-    DEBUG => 0,
+    DEBUG => $ENV{AMW_DEBUG},
 };
 
 use File::Basename;
@@ -30,11 +30,11 @@ Text::Amuse::Compile - Compiler for Text::Amuse
 
 =head1 VERSION
 
-Version 0.42
+Version 0.43
 
 =cut
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 =head1 SYNOPSIS
 
@@ -149,10 +149,6 @@ copy of C<extra_opts>
 
 Do not force bcor=0 and oneside for plain tex and pdf
 
-=item debug
-
-Slow down the compilation sleeping for a while. DO NOT USE.
-
 =back
 
 Template directory:
@@ -190,7 +186,6 @@ has html   => (is => 'ro', isa => Bool, default => sub { 0 });
 has bare_html => (is => 'ro', isa => Bool, default => sub { 0 });
 
 has cleanup   => (is => 'ro', isa => Bool, default => sub { 0 });
-has debug     => (is => 'ro', isa => Bool, default => sub { 0 });
 
 has ttdir     => (is => 'ro',   isa => Maybe[Str]);
 has templates => (is => 'lazy', isa => Object);
@@ -209,7 +204,8 @@ sub BUILDARGS {
     $params{extra_opts} = { %{ delete $params{extra} || {} } };
     my $all = 1;
     if (exists $params{slides}) {
-        $params{sl_pdf} ||= $params{slides};
+        my $slides = delete $params{slides};
+        $params{sl_pdf} ||= $slides;
     }
     foreach my $format ($class->available_methods) {
         if (exists $params{$format}) {
@@ -581,12 +577,11 @@ sub _muse_compile {
       or die "Cannot open $statusfile\n!";
     flock($fhlock, LOCK_EX | LOCK_NB) or die "Cannot acquire lock on $statusfile";
 
-    if ($self->debug) {
-        sleep 5;
-    }
+    sleep 5 if DEBUG;
+
     my @fatals;
+    $muse->purge_all unless DEBUG;
     if ($muse->is_deleted) {
-        $muse->purge_all;
         $self->_write_status_file($fhlock, 'DELETED');
         return;
     }
